contourpy: Python library for calculating contours of 2D quadrilateral grids
============================================================================

Description
-----------

Python library for calculating contours of 2D quadrilateral grids

License
-------

BSD-3-Clause

Upstream Contact
----------------

https://pypi.org/project/contourpy/

